@@ -585,7 +585,18 @@ class emailmgmt {
             if ($this->mail_client) {
                 try {
                     $username_part = explode('@', $source_email)[0];
-                    // Pass all destinations as an array to the mail server
+                    
+                    // If there are existing destinations, we need to delete the forwarder first
+                    if (!empty($existing_destinations)) {
+                        try {
+                            $this->mail_client->deleteEmailForwarder($source_email);
+                        } catch (Exception $e) {
+                            // Ignore deletion errors - the forwarder might not exist on mail server
+                            error_log("Note: Could not delete existing forwarder (might not exist): " . $e->getMessage());
+                        }
+                    }
+                    
+                    // Now create the forwarder with all destinations
                     $this->mail_client->createEmailForwarder($source_email, $all_destinations, $username_part);
                 } catch (Exception $e) {
                     error_log("Failed to update email forwarder on mail server: " . $e->getMessage());
@@ -654,11 +665,16 @@ class emailmgmt {
             // Update mail server
             if ($this->mail_client && $forwarder['source_email']) {
                 try {
-                    if (empty($remaining_destinations)) {
-                        // No more destinations, delete the forwarder entirely
+                    // First, always try to delete the existing forwarder
+                    try {
                         $this->mail_client->deleteEmailForwarder($forwarder['source_email']);
-                    } else {
-                        // Update the forwarder with remaining destinations
+                    } catch (Exception $e) {
+                        // Ignore deletion errors - the forwarder might not exist on mail server
+                        error_log("Note: Could not delete existing forwarder (might not exist): " . $e->getMessage());
+                    }
+                    
+                    // If there are remaining destinations, recreate the forwarder with them
+                    if (!empty($remaining_destinations)) {
                         $username_part = explode('@', $forwarder['source_email'])[0];
                         $this->mail_client->createEmailForwarder($forwarder['source_email'], $remaining_destinations, $username_part);
                     }
