@@ -285,6 +285,12 @@ if ($current_user) {
                             <span class="fw-bold">mysql:3306</span>
                         </div>
                     </div>
+                    <div class="col-12">
+                        <div class="d-flex justify-content-between align-items-center border-bottom pb-2 mb-2">
+                            <span class="text-muted">PostgreSQL Database:</span>
+                            <span class="fw-bold">postgresql:5432</span>
+                        </div>
+                    </div>
                     <div class="col-12">
                         <div class="d-flex justify-content-between align-items-center">
                             <span class="text-muted">Memcache (Sessions):</span>
@@ -295,7 +301,7 @@ if ($current_user) {
                 <div class="mt-3 p-2 bg-dark rounded">
                     <small class="text-muted">
                         <i class="fa fa-info-circle me-1"></i>
-                        Use these Docker container names for your applications running in containers. MySQL is for database access, Memcache is for session management.
+                        Use these Docker container names for your applications running in containers. MySQL is for MySQL databases, PostgreSQL is for PostgreSQL databases, Memcache is for session management.
                     </small>
                 </div>
             </div>
